==> roundcubemail-1.2.0.tgz: roundcubemail/program/js/tinymce/langs/et.js <==
tinymce.addI18n('et',{
"Cut": "L\u00f5ika",
"Heading 5": "Pealkiri 5",
"Header 2": "Pealkiri 2",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Sinu veebilehitseja ei toeta otsest ligip\u00e4\u00e4su l\u00f5ikelauale. Palun kasuta selle asemel klaviatuuri kiirk\u00e4sklusi Ctrl+X\/C\/V.",
"Heading 4": "Pealkiri 4",
"Div": "Sektsioon",
"Heading 2": "Pealkiri 2",
"Paste": "Kleebi",
"Close": "Sulge",
"Font Family": "Kirjastiilid",
"Pre": "Eelvormindatud",
"Align right": "Joonda paremale",
"New document": "Uus dokument",
"Blockquote": "Plokktsitaat",
"Numbered list": "J\u00e4rjestatud loend",
"Heading 1": "Pealkiri 1",
"Headings": "Pealkirjad",
"Increase indent": "Suurenda taanet",
"Formats": "Vormingud",
"Headers": "P\u00e4ised",
"Select all": "Vali k\u00f5ik",
"Header 3": "Pealkiri 3",
"Blocks": "Plokid",
"Undo": "V\u00f5ta tagasi",
"Strikethrough": "L\u00e4bikriipsutatud",
"Bullet list": "J\u00e4rjestamata loend",
"Header 1": "Pealkiri 1",
"Superscript": "\u00dclaindeks",
"Clear formatting": "Puhasta vorming",
"Font Sizes": "Kirja suurused",
"Subscript": "Alaindeks",
"Header 6": "Pealkiri 6",
"Redo": "Tee uuesti",
"Paragraph": "L\u00f5ik",
"Ok": "Ok",
"Bold": "Rasvane",
"Code": "Kood",
"Italic": "Kaldkiri",
"Align center": "Joonda keskele",
"Header 5": "Pealkiri 5",
"Heading 6": "Pealkiri 6",
"Heading 3": "Pealkiri 3",
"Decrease indent": "V\u00e4henda taanet",
"Header 4": "Pealkiri 4",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Asetamine on n\u00fc\u00fcd tekstire\u017eiimis. Sisu asetatakse n\u00fc\u00fcd lihttekstina, kuni sa l\u00fclitad selle valiku v\u00e4lja.",
"Underline": "Allakriipsutatud",
"Cancel": "Katkesta",
"Justify": "Joonda r\u00f6\u00f6pselt",
"Inline": "Reasisene",
"Copy": "Kopeeri",
"Align left": "Joonda vasakule",
"Visual aids": "N\u00e4itevahendid",
"Lower Greek": "Kreeka v\u00e4iket\u00e4hed (\u03b1, \u03b2, \u03b3)",
"Square": "Ruut",
"Default": "Vaikimisi",
"Lower Alpha": "V\u00e4iket\u00e4hed (a, b, c)",
"Circle": "Ring",
"Disc": "Ketas",
"Upper Alpha": "Suurt\u00e4hed (A, B, C)",
"Upper Roman": "Rooma suurt\u00e4hed (I, II, III)",
"Lower Roman": "Rooma v\u00e4iket\u00e4hed (i, ii, iii)",
"Name": "Nimi",
"Anchor": "Ankur",
"You have unsaved changes are you sure you want to navigate away?": "Sul on salvestamata muudatusi. Oled Sa kindel, et soovid mujale navigeeruda?",
"Restore last draft": "Taasta viimane mustand",
"Special character": "Erim\u00e4rk",
"Source code": "L\u00e4htekood",
"B": "B",
"R": "R",
"G": "G",
"Color": "V\u00e4rv",
"Right to left": "Paremalt vasakule",
"Left to right": "Vasakult paremale",
"Emoticons": "Emotikonid",
"Robots": "Robotid",
"Document properties": "Dokumendi omadused",
"Title": "Pealkiri",
"Keywords": "M\u00e4rks\u00f5nad",
"Encoding": "M\u00e4rgistik",
"Description": "Kirjeldus",
"Author": "Autor",
"Fullscreen": "T\u00e4isekraan",
"Horizontal line": "Horisontaaljoon",
"Horizontal space": "Reavahe",
"Insert\/edit image": "Lisa\/muuda pilt",
"General": "\u00dcldine",
"Advanced": "T\u00e4iendavad seaded",
"Source": "Allikas",
"Border": "\u00c4\u00e4ris",
"Constrain proportions": "S\u00e4ilita kuvasuhe",
"Vertical space": "P\u00fcstine vahe",
"Image description": "Pildi kirjeldus",
"Style": "Stiil",
"Dimensions": "M\u00f5\u00f5tmed",
"Insert image": "Lisa pilt",
"Zoom in": "Suumi sisse",
"Contrast": "Kontrast",
"Back": "Tagasi",
"Gamma": "Gamma",
"Flip horizontally": "Peegelda horisontaalselt",
"Resize": "Muuda suurust",
"Sharpen": "Teravamaks",
"Zoom out": "Suumi v\u00e4lja",
"Image options": "Pildi valikud",
"Apply": "Rakenda",
"Brightness": "Heledus",
"Rotate clockwise": "P\u00f6\u00f6ra p\u00e4rip\u00e4eva",
"Rotate counterclockwise": "P\u00f6\u00f6ra vastup\u00e4eva",
"Edit image": "Muuda pilti",
"Color levels": "V\u00e4rvi tasemed",
"Crop": "L\u00f5ika",
"Orientation": "Suund",
"Flip vertically": "Peegelda vertikaalselt",
"Invert": "P\u00f6\u00f6ra v\u00e4rvid",
"Insert date\/time": "Lisa kuup\u00e4ev\/kellaaeg",
"Remove link": "Eemalda link",
"Url": "Viide (url)",
"Text to display": "Kuvatav tekst",
"Anchors": "Ankrud",
"Insert link": "Lisa link",
"New window": "Uus aken",
"None": "Puudub",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "URL, mille sa sisestasid, n\u00e4ib olevat v\u00e4line link. Kas sa soovid lisada sellele eesliite http:\/\/ ?",
"Target": "Sihtm\u00e4rk",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "URL, mille sa sisestasid, n\u00e4ib olevat e-posti aadress. Kas sa soovid lisada sellele eesliite mailto: ?",
"Insert\/edit link": "Lisa\/muuda link",
"Insert\/edit video": "Lisa\/muuda video",
"Poster": "Lisaja",
"Alternative source": "Teine allikas",
"Paste your embed code below:": "Kleebi oma manustamiskood siia alla:",
"Insert video": "Lisa video",
"Embed": "Manusta",
"Nonbreaking space": "T\u00fchim\u00e4rk (nbsp)",
"Page break": "Lehevahetus",
"Paste as text": "Aseta tekstina",
"Preview": "Eelvaade",
"Print": "Tr\u00fcki",
"Save": "Salvesta",
"Could not find the specified string.": "Ei suutnud leida etteantud s\u00f5net.",
"Replace": "Asenda",
"Next": "J\u00e4rg",
"Whole words": "Terviks\u00f5nad",
"Find and replace": "Otsi ja asenda",
"Replace with": "Asendus",
"Find": "Otsi",
"Replace all": "Asenda k\u00f5ik",
"Match case": "Erista suur- ja v\u00e4iket\u00e4hti",
"Prev": "Eelm",
"Spellcheck": "\u00d5igekirja kontroll",
"Finish": "L\u00f5peta",
"Ignore all": "Eira k\u00f5iki",
"Ignore": "Eira",
"Add to Dictionary": "Lisa s\u00f5naraamatusse",
"Insert row before": "Lisa rida enne",
"Rows": "Read",
"Height": "K\u00f5rgus",
"Paste row after": "Kleebi rida j\u00e4rele",
"Alignment": "Joondus",
"Border color": "Piirjoone v\u00e4rv",
"Column group": "Veergude r\u00fchm",
"Row": "Rida",
"Insert column before": "Lisa tulp enne",
"Split cell": "T\u00fckelda lahter",
"Cell padding": "Lahtri sisu ja tabeli \u00e4\u00e4rise vahe",
"Cell spacing": "Lahtrivahe",
"Row type": "Rea t\u00fc\u00fcp",
"Insert table": "Lisa tabel",
"Body": "P\u00f5hiosa",
"Caption": "Alapealkiri",
"Footer": "Jalus",
"Delete row": "Kustuta rida",
"Paste row before": "Kleebi rida enne",
"Scope": "Ulatus",
"Delete table": "Kustuta tabel",
"H Align": "H Joondus",
"Top": "\u00dcleval",
"Header cell": "P\u00e4islahter",
"Column": "Tulp",
"Row group": "Ridade r\u00fchm",
"Cell": "Lahter",
"Middle": "Keskel",
"Cell type": "Lahtri t\u00fc\u00fcp",
"Copy row": "Kopeeri rida",
"Row properties": "Rea omadused",
"Table properties": "Tabeli omadused",
"Bottom": "All",
"V Align": "V Joondus",
"Header": "P\u00e4is",
"Right": "Paremal",
"Insert column after": "Lisa tulp j\u00e4rele",
"Cols": "Veerud",
"Insert row after": "Lisa rida j\u00e4rele",
"Width": "Laius",
"Cell properties": "Lahtri omadused",
"Left": "Vasakul",
"Cut row": "L\u00f5ika rida",
"Delete column": "Kustuta tulp",
"Center": "Keskel",
"Merge cells": "\u00dchenda lahtrid",
"Insert template": "Lisa mall",
"Templates": "Mallid",
"Background color": "Tausta v\u00e4rv",
"Custom...": "Kohandatud...",
"Custom color": "Kohandatud v\u00e4rv",
"No color": "V\u00e4rvi pole",
"Text color": "Teksti v\u00e4rv",
"Show blocks": "N\u00e4ita plokke",
"Show invisible characters": "N\u00e4ita peidetud m\u00e4rke",
"Words: {0}": "S\u00f5nu: {0}",
"Insert": "Sisesta",
"File": "Fail",
"Edit": "Muuda",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Rikastatud teksti ala. Men\u00fc\u00fc jaoks vajuta ALT-F9. T\u00f6\u00f6riistariba jaoks vajuta ALT-F10. Abi saamiseks vajuta ALT-0.",
"Tools": "T\u00f6\u00f6riistad",
"View": "Vaade",
"Table": "Tabel",
"Format": "Vorming"
});

==> roundcubemail-1.3.5.tgz: roundcubemail/program/js/tinymce/langs/et.js <==
tinymce.addI18n('et',{
"Redo": "Tee uuesti",
"Undo": "V\u00f5ta tagasi",
"Cut": "L\u00f5ika",
"Copy": "Kopeeri",
"Paste": "Kleebi",
"Select all": "Vali k\u00f5ik",
"New document": "Uus dokument",
"Ok": "Ok",
"Cancel": "Katkesta",
"Visual aids": "N\u00e4itevahendid",
"Bold": "Rasvane",
"Italic": "Kaldkiri",
"Underline": "Allakriipsutatud",
"Strikethrough": "L\u00e4bikriipsutatud",
"Superscript": "\u00dclaindeks",
"Subscript": "Alaindeks",
"Clear formatting": "Puhasta vorming",
"Align left": "Joonda vasakule",
"Align center": "Joonda keskele",
"Align right": "Joonda paremale",
"Justify": "Joonda r\u00f6\u00f6pselt",
"Bullet list": "J\u00e4rjestamata loend",
"Numbered list": "J\u00e4rjestatud loend",
"Decrease indent": "V\u00e4henda taanet",
"Increase indent": "Suurenda taanet",
"Close": "Sulge",
"Formats": "Vormingud",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Sinu veebilehitseja ei toeta otsest ligip\u00e4\u00e4su l\u00f5ikelauale. Palun kasuta selle asemel klaviatuuri kiirk\u00e4sklusi Ctrl+X\/C\/V.",
"Headers": "P\u00e4ised",
"Header 1": "Pealkiri 1",
"Header 2": "Pealkiri 2",
"Header 3": "Pealkiri 3",
"Header 4": "Pealkiri 4",
"Header 5": "Pealkiri 5",
"Header 6": "Pealkiri 6",
"Headings": "Pealkirjad",
"Heading 1": "Pealkiri 1",
"Heading 2": "Pealkiri 2",
"Heading 3": "Pealkiri 3",
"Heading 4": "Pealkiri 4",
"Heading 5": "Pealkiri 5",
"Heading 6": "Pealkiri 6",
"Div": "Sektsioon",
"Pre": "Eelvormindatud",
"Code": "Kood",
"Paragraph": "L\u00f5ik",
"Blockquote": "Plokktsitaat",
"Inline": "Reasisene",
"Blocks": "Plokid",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Asetamine on n\u00fc\u00fcd tekstire\u017eiimis. Sisu asetatakse n\u00fc\u00fcd lihttekstina, kuni sa l\u00fclitad selle valiku v\u00e4lja.",
"Font Family": "Kirjastiilid",
"Font Sizes": "Kirja suurused",
"Class": "Klass",
"Browse for an image": "Sirvi pilte",
"OR": "V\u00d5I",
"Drop an image here": "Kukuta pilt siia",
"Upload": "\u00dcles laadimine",
"Block": "Plokk",
"Align": "Joonda",
"Default": "Vaikimisi",
"Circle": "Ring",
"Disc": "Ketas",
"Square": "Ruut",
"Lower Alpha": "V\u00e4iket\u00e4hed (a, b, c)",
"Lower Greek": "Kreeka v\u00e4iket\u00e4hed (\u03b1, \u03b2, \u03b3)",
"Lower Roman": "Rooma v\u00e4iket\u00e4hed (i, ii, iii)",
"Upper Alpha": "Suurt\u00e4hed (A, B, C)",
"Upper Roman": "Rooma suurt\u00e4hed (I, II, III)",
"Anchor": "Ankur",
"Name": "Nimi",
"Id": "ID",
"Id should start with a letter, followed only by letters, numbers, dashes, dots, colons or underscores.": "ID peaks algama t\u00e4hega ning sellele peaks j\u00e4rgnema ainult t\u00e4hed, arvud, sidekriipsud, punktid, koolonid v\u00f5i alakriipsud.",
"You have unsaved changes are you sure you want to navigate away?": "Sul on salvestamata muudatusi. Oled Sa kindel, et soovid mujale navigeeruda?",
"Restore last draft": "Taasta viimane mustand",
"Special character": "Erim\u00e4rk",
"Source code": "L\u00e4htekood",
"Insert\/Edit code sample": "Sisesta\/muuda koodin\u00e4idis",
"Language": "Keel",
"Code sample": "Code sample",
"Color": "V\u00e4rv",
"R": "R",
"G": "G",
"B": "B",
"Left to right": "Vasakult paremale",
"Right to left": "Paremalt vasakule",
"Emoticons": "Emotikonid",
"Document properties": "Dokumendi omadused",
"Title": "Pealkiri",
"Keywords": "M\u00e4rks\u00f5nad",
"Description": "Kirjeldus",
"Robots": "Robotid",
"Author": "Autor",
"Encoding": "M\u00e4rgistik",
"Fullscreen": "T\u00e4isekraan",
"Action": "Action",
"Shortcut": "Shortcut",
"Help": "Help",
"Address": "Address",
"Focus to menubar": "Focus to menubar",
"Focus to toolbar": "Focus to toolbar",
"Focus to element path": "Focus to element path",
"Focus to contextual toolbar": "Focus to contextual toolbar",
"Insert link (if link plugin activated)": "Insert link (if link plugin activated)",
"Save (if save plugin activated)": "Save (if save plugin activated)",
"Find (if searchreplace plugin activated)": "Find (if searchreplace plugin activated)",
"Plugins installed ({0}):": "Plugins installed ({0}):",
"Premium plugins:": "Premium plugins:",
"Learn more...": "Learn more...",
"You are using {0}": "You are using {0}",
"Plugins": "Plugins",
"Handy Shortcuts": "Handy Shortcuts",
"Horizontal line": "Horisontaaljoon",
"Insert\/edit image": "Lisa\/muuda pilt",
"Image description": "Pildi kirjeldus",
"Source": "Allikas",
"Dimensions": "M\u00f5\u00f5tmed",
"Constrain proportions": "S\u00e4ilita kuvasuhe",
"General": "\u00dcldine",
"Advanced": "T\u00e4iendavad seaded",
"Style": "Stiil",
"Vertical space": "P\u00fcstine vahe",
"Horizontal space": "Reavahe",
"Border": "\u00c4\u00e4ris",
"Insert image": "Lisa pilt",
"Image": "Pilt",
"Image list": "Image list",
"Rotate counterclockwise": "P\u00f6\u00f6ra vastup\u00e4eva",
"Rotate clockwise": "P\u00f6\u00f6ra p\u00e4rip\u00e4eva",
"Flip vertically": "Peegelda vertikaalselt",
"Flip horizontally": "Peegelda horisontaalselt",
"Edit image": "Muuda pilti",
"Image options": "Pildi valikud",
"Zoom in": "Suumi sisse",
"Zoom out": "Suumi v\u00e4lja",
"Crop": "L\u00f5ika",
"Resize": "Muuda suurust",
"Orientation": "Suund",
"Brightness": "Heledus",
"Sharpen": "Teravamaks",
"Contrast": "Kontrast",
"Color levels": "V\u00e4rvi tasemed",
"Gamma": "Gamma",
"Invert": "P\u00f6\u00f6ra v\u00e4rvid",
"Apply": "Rakenda",
"Back": "Tagasi",
"Insert date\/time": "Lisa kuup\u00e4ev\/kellaaeg",
"Date\/time": "Kuup\u00e4ev\/kellaaeg",
"Insert link": "Lisa link",
"Insert\/edit link": "Lisa\/muuda link",
"Text to display": "Kuvatav tekst",
"Url": "Viide (url)",
"Target": "Sihtm\u00e4rk",
"None": "Puudub",
"New window": "Uus aken",
"Remove link": "Eemalda link",
"Anchors": "Ankrud",
"Link": "Link",
"Paste or type a link": "Aseta v\u00f5i sisesta link",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "URL, mille sa sisestasid, n\u00e4ib olevat e-posti aadress. Kas sa soovid lisada sellele eesliite mailto: ?",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "URL, mille sa sisestasid, n\u00e4ib olevat v\u00e4line link. Kas sa soovid lisada sellele eesliite http:\/\/ ?",
"Link list": "Link list",
"Insert video": "Lisa video",
"Insert\/edit video": "Lisa\/muuda video",
"Insert\/edit media": "Lisa\/muuda multimeediat",
"Alternative source": "Teine allikas",
"Poster": "Lisaja",
"Paste your embed code below:": "Kleebi oma manustamiskood siia alla:",
"Embed": "Manusta",
"Media": "Multimeedia",
"Nonbreaking space": "T\u00fchim\u00e4rk (nbsp)",
"Page break": "Lehevahetus",
"Paste as text": "Aseta tekstina",
"Preview": "Eelvaade",
"Print": "Tr\u00fcki",
"Save": "Salvesta",
"Find": "Otsi",
"Replace with": "Asendus",
"Replace": "Asenda",
"Replace all": "Asenda k\u00f5ik",
"Prev": "Eelm",
"Next": "J\u00e4rg",
"Find and replace": "Otsi ja asenda",
"Could not find the specified string.": "Ei suutnud leida etteantud s\u00f5net.",
"Match case": "Erista suur- ja v\u00e4iket\u00e4hti",
"Whole words": "Terviks\u00f5nad",
"Spellcheck": "\u00d5igekirja kontroll",
"Ignore": "Eira",
"Ignore all": "Eira k\u00f5iki",
"Finish": "L\u00f5peta",
"Add to Dictionary": "Lisa s\u00f5naraamatusse",
"Insert table": "Lisa tabel",
"Table properties": "Tabeli omadused",
"Delete table": "Kustuta tabel",
"Cell": "Lahter",
"Row": "Rida",
"Column": "Tulp",
"Cell properties": "Lahtri omadused",
"Merge cells": "\u00dchenda lahtrid",
"Split cell": "T\u00fckelda lahter",
"Insert row before": "Lisa rida enne",
"Insert row after": "Lisa rida j\u00e4rele",
"Delete row": "Kustuta rida",
"Row properties": "Rea omadused",
"Cut row": "L\u00f5ika rida",
"Copy row": "Kopeeri rida",
"Paste row before": "Kleebi rida enne",
"Paste row after": "Kleebi rida j\u00e4rele",
"Insert column before": "Lisa tulp enne",
"Insert column after": "Lisa tulp j\u00e4rele",
"Delete column": "Kustuta tulp",
"Cols": "Veerud",
"Rows": "Read",
"Width": "Laius",
"Height": "K\u00f5rgus",
"Cell spacing": "Lahtrivahe",
"Cell padding": "Lahtri sisu ja tabeli \u00e4\u00e4rise vahe",
"Caption": "Alapealkiri",
"Left": "Vasakul",
"Center": "Keskel",
"Right": "Paremal",
"Cell type": "Lahtri t\u00fc\u00fcp",
"Scope": "Ulatus",
"Alignment": "Joondus",
"H Align": "H Joondus",
"V Align": "V Joondus",
"Top": "\u00dcleval",
"Middle": "Keskel",
"Bottom": "All",
"Header cell": "P\u00e4islahter",
"Row group": "Ridade r\u00fchm",
"Column group": "Veergude r\u00fchm",
"Row type": "Rea t\u00fc\u00fcp",
"Header": "P\u00e4is",
"Body": "P\u00f5hiosa",
"Footer": "Jalus",
"Border color": "Piirjoone v\u00e4rv",
"Insert template": "Lisa mall",
"Templates": "Mallid",
"Template": "Template",
"Text color": "Teksti v\u00e4rv",
"Background color": "Tausta v\u00e4rv",
"Custom...": "Kohandatud...",
"Custom color": "Kohandatud v\u00e4rv",
"No color": "V\u00e4rvi pole",
"Table of Contents": "Sisukord",
"Show blocks": "N\u00e4ita plokke",
"Show invisible characters": "N\u00e4ita peidetud m\u00e4rke",
"Words: {0}": "S\u00f5nu: {0}",
"{0} words": "{0} words",
"File": "Fail",
"Edit": "Muuda",
"Insert": "Sisesta",
"View": "Vaade",
"Format": "Vorming",
"Table": "Tabel",
"Tools": "T\u00f6\u00f6riistad",
"Powered by {0}": "Powered by {0}",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Rikastatud teksti ala. Men\u00fc\u00fc jaoks vajuta ALT-F9. T\u00f6\u00f6riistariba jaoks vajuta ALT-F10. Abi saamiseks vajuta ALT-0."
});
